@@ -9,6 +9,8 @@ class TfidfVectorizer(VectorizableToken):
     '''
     # Document
     __collection = []
+
+    __vector_list = None
     
     def __init__(self, token_list_list):
         '''
@@ -30,4 +32,19 @@ class TfidfVectorizer(VectorizableToken):
             [vector of token, vector of token, vector of token, ...]
         '''
         vector_list = [self.__collection.tf_idf(token, self.__collection) for token in token_list]
+        self.__vector_list = vector_list
         return vector_list
+
+    def get_dim(self):
+        ''' getter '''
+        if self.__vector_list is None:
+            _ = self.vectorize(["dummy"])
+        
+        return len(self.__vector_list)
+
+    def set_dim(self, value):
+        ''' setter '''
+        raise TypeError("This property must be read-only.")
+    
+    dim = property(get_dim, set_dim)
+
